# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"U\n\x19LookupOffsetByTimeRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"D\n\x1aLookupOffsetByTimeResponse\x12\x1b\n\x06offset\x18\x01 \x01(\x03H\x00R\x06offset\x88\x01\x01\x42\t\n\x07_offset\"\x85\x02\n\x15OpenCommitmentRequest\x12\x1e\n\ncommitment\x18\x01 \x01(\x0cR\ncommitment\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\x12N\n$computed_for_counter_participant_uid\x18\x03 \x01(\tR computedForCounterParticipantUid\x12\x42\n\x0fperiod_end_tick\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rperiodEndTick\".\n\x16OpenCommitmentResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"]\n\x16\x43ommitmentContractMeta\x12\x10\n\x03\x63id\x18\x01 \x01(\x0cR\x03\x63id\x12\x31\n\x14reassignment_counter\x18\x02 \x01(\x03R\x13reassignmentCounter\"\xd6\x01\n!InspectCommitmentContractsRequest\x12\x12\n\x04\x63ids\x18\x01 \x03(\x0cR\x04\x63ids\x12\x38\n\x18\x65xpected_synchronizer_id\x18\x02 \x01(\tR\x16\x65xpectedSynchronizerId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12)\n\x10\x64ownload_payload\x18\x04 \x01(\x08R\x0f\x64ownloadPayload\":\n\"InspectCommitmentContractsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\x83\x02\n\x12\x43ommitmentContract\x12\x10\n\x03\x63id\x18\x01 \x01(\x0cR\x03\x63id\x12\x45\n\x1f\x61\x63tive_on_expected_synchronizer\x18\x02 \x01(\x08R\x1c\x61\x63tiveOnExpectedSynchronizer\x12\x1f\n\x08\x63ontract\x18\x03 \x01(\x0cH\x00R\x08\x63ontract\x88\x01\x01\x12\x66\n\x06states\x18\x04 \x03(\x0b\x32N.com.digitalasset.canton.admin.participant.v30.ContractState.SynchronizerStateR\x06statesB\x0b\n\t_contract\"\xcc\x08\n\rContractState\x1a\xbe\x04\n\x11SynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12`\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ContractState.CreatedH\x00R\x07\x63reated\x12\x63\n\x08\x61rchived\x18\x03 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.ContractState.ArchivedH\x00R\x08\x61rchived\x12i\n\nunassigned\x18\x04 \x01(\x0b\x32G.com.digitalasset.canton.admin.participant.v30.ContractState.UnassignedH\x00R\nunassigned\x12\x63\n\x08\x61ssigned\x18\x05 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.ContractState.AssignedH\x00R\x08\x61ssigned\x12`\n\x07unknown\x18\x06 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ContractState.UnknownH\x00R\x07unknownB\x07\n\x05state\x1a\t\n\x07\x43reated\x1a\xc0\x01\n\x08\x41ssigned\x12>\n\x1breassignment_counter_target\x18\x01 \x01(\x03R\x19reassignmentCounterTarget\x12t\n\x0freassignment_id\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.ContractState.ReassignmentIdR\x0ereassignmentId\x1a\n\n\x08\x41rchived\x1a\xf2\x01\n\nUnassigned\x12\x34\n\x16target_synchronizer_id\x18\x01 \x01(\tR\x14targetSynchronizerId\x12\x38\n\x18reassignment_counter_src\x18\x02 \x01(\x03R\x16reassignmentCounterSrc\x12t\n\x0freassignment_id\x18\x03 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.ContractState.ReassignmentIdR\x0ereassignmentId\x1a\t\n\x07Unknown\x1a \n\x0eReassignmentId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xd1\x02\n#LookupReceivedAcsCommitmentsRequest\x12\x65\n\x0btime_ranges\x18\x01 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.SynchronizerTimeRangeR\ntimeRanges\x12\x36\n\x17\x63ounter_participant_ids\x18\x02 \x03(\tR\x15\x63ounterParticipantIds\x12q\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\"\x97\x01\n$LookupReceivedAcsCommitmentsResponse\x12o\n\x08received\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentPerSynchronizerR\x08received\"\x8d\x01\n\tTimeRange\x12\x41\n\x0e\x66rom_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rfromExclusive\x12=\n\x0cto_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btoInclusive\"\xa8\x01\n\x15SynchronizerTimeRange\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12Y\n\x08interval\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.participant.v30.TimeRangeH\x00R\x08interval\x88\x01\x01\x42\x0b\n\t_interval\"\xa2\x01\n\x08Interval\x12L\n\x14start_tick_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12startTickExclusive\x12H\n\x12\x65nd_tick_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ndTickInclusive\"\x9c\x03\n\x15ReceivedAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12\x43\n\x1eorigin_counter_participant_uid\x18\x02 \x01(\tR\x1boriginCounterParticipantUid\x12\x34\n\x13received_commitment\x18\x03 \x01(\x0cH\x00R\x12receivedCommitment\x88\x01\x01\x12*\n\x0eown_commitment\x18\x04 \x01(\x0cH\x01R\rownCommitment\x88\x01\x01\x12\\\n\x05state\x18\x05 \x01(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x05stateB\x16\n\x14_received_commitmentB\x11\n\x0f_own_commitment\"\xb1\x01\n$ReceivedAcsCommitmentPerSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12`\n\x08received\x18\x02 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentR\x08received\"\x90\x03\n\x11SentAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12?\n\x1c\x64\x65st_counter_participant_uid\x18\x02 \x01(\tR\x19\x64\x65stCounterParticipantUid\x12*\n\x0eown_commitment\x18\x03 \x01(\x0cH\x00R\rownCommitment\x88\x01\x01\x12\x34\n\x13received_commitment\x18\x04 \x01(\x0cH\x01R\x12receivedCommitment\x88\x01\x01\x12X\n\x05state\x18\x05 \x01(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x05stateB\x11\n\x0f_own_commitmentB\x16\n\x14_received_commitment\"\xa1\x01\n SentAcsCommitmentPerSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12T\n\x04sent\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentR\x04sent\"\xc9\x02\n\x1fLookupSentAcsCommitmentsRequest\x12\x65\n\x0btime_ranges\x18\x01 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.SynchronizerTimeRangeR\ntimeRanges\x12\x36\n\x17\x63ounter_participant_ids\x18\x02 \x03(\tR\x15\x63ounterParticipantIds\x12m\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\"\x87\x01\n LookupSentAcsCommitmentsResponse\x12\x63\n\x04sent\x18\x01 \x03(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentPerSynchronizerR\x04sent\"\xbb\x02\n(SlowCounterParticipantSynchronizerConfig\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\x12\x44\n\x1e\x64istinguished_participant_uids\x18\x02 \x03(\tR\x1c\x64istinguishedParticipantUids\x12\x37\n\x17threshold_distinguished\x18\x03 \x01(\x04R\x16thresholdDistinguished\x12+\n\x11threshold_default\x18\x04 \x01(\x04R\x10thresholdDefault\x12\x38\n\x18participant_uids_metrics\x18\x05 \x03(\tR\x16participantUidsMetrics\"\x9f\x01\n*SetConfigForSlowCounterParticipantsRequest\x12q\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantSynchronizerConfigR\x07\x63onfigs\"-\n+SetConfigForSlowCounterParticipantsResponse\"W\n*GetConfigForSlowCounterParticipantsRequest\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"\xa0\x01\n+GetConfigForSlowCounterParticipantsResponse\x12q\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantSynchronizerConfigR\x07\x63onfigs\"\xbb\x02\n\x16\x43ounterParticipantInfo\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12)\n\x10intervals_behind\x18\x03 \x01(\x04R\x0fintervalsBehind\x12<\n\x0c\x62\x65hind_since\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0b\x62\x65hindSince\x12W\n\x1a\x61s_of_sequencing_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x61sOfSequencingTimestamp\"\xc5\x01\n/GetIntervalsBehindForCounterParticipantsRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\x12!\n\tthreshold\x18\x03 \x01(\x04H\x00R\tthreshold\x88\x01\x01\x42\x0c\n\n_threshold\"\xa4\x01\n0GetIntervalsBehindForCounterParticipantsResponse\x12p\n\x10intervals_behind\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.CounterParticipantInfoR\x0fintervalsBehind\"?\n\x14\x43ountInFlightRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\"{\n\x15\x43ountInFlightResponse\x12/\n\x13pending_submissions\x18\x01 \x01(\rR\x12pendingSubmissions\x12\x31\n\x14pending_transactions\x18\x02 \x01(\rR\x13pendingTransactions*\xe4\x01\n\x17ReceivedCommitmentState\x12)\n%RECEIVED_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1fRECEIVED_COMMITMENT_STATE_MATCH\x10\x01\x12&\n\"RECEIVED_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"RECEIVED_COMMITMENT_STATE_BUFFERED\x10\x03\x12)\n%RECEIVED_COMMITMENT_STATE_OUTSTANDING\x10\x04*\xa9\x01\n\x13SentCommitmentState\x12%\n!SENT_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSENT_COMMITMENT_STATE_MATCH\x10\x01\x12\"\n\x1eSENT_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"SENT_COMMITMENT_STATE_NOT_COMPARED\x10\x03\x32\x83\x0e\n\x1cParticipantInspectionService\x12\xa9\x01\n\x12LookupOffsetByTime\x12H.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTimeRequest\x1aI.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTimeResponse\x12\x9f\x01\n\x0eOpenCommitment\x12\x44.com.digitalasset.canton.admin.participant.v30.OpenCommitmentRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.OpenCommitmentResponse0\x01\x12\xc3\x01\n\x1aInspectCommitmentContracts\x12P.com.digitalasset.canton.admin.participant.v30.InspectCommitmentContractsRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.InspectCommitmentContractsResponse0\x01\x12\xbb\x01\n\x18LookupSentAcsCommitments\x12N.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitmentsRequest\x1aO.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitmentsResponse\x12\xc7\x01\n\x1cLookupReceivedAcsCommitments\x12R.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitmentsRequest\x1aS.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitmentsResponse\x12\xdc\x01\n#SetConfigForSlowCounterParticipants\x12Y.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipantsRequest\x1aZ.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipantsResponse\x12\xdc\x01\n#GetConfigForSlowCounterParticipants\x12Y.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipantsRequest\x1aZ.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipantsResponse\x12\xeb\x01\n(GetIntervalsBehindForCounterParticipants\x12^.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipantsRequest\x1a_.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipantsResponse\x12\x9a\x01\n\rCountInFlight\x12\x43.com.digitalasset.canton.admin.participant.v30.CountInFlightRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.CountInFlightResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_start=6665
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_end=6893
  _globals['_SENTCOMMITMENTSTATE']._serialized_start=6896
  _globals['_SENTCOMMITMENTSTATE']._serialized_end=7065
  _globals['_LOOKUPOFFSETBYTIMEREQUEST']._serialized_start=198
  _globals['_LOOKUPOFFSETBYTIMEREQUEST']._serialized_end=283
  _globals['_LOOKUPOFFSETBYTIMERESPONSE']._serialized_start=285
  _globals['_LOOKUPOFFSETBYTIMERESPONSE']._serialized_end=353
  _globals['_OPENCOMMITMENTREQUEST']._serialized_start=356
  _globals['_OPENCOMMITMENTREQUEST']._serialized_end=617
  _globals['_OPENCOMMITMENTRESPONSE']._serialized_start=619
  _globals['_OPENCOMMITMENTRESPONSE']._serialized_end=665
  _globals['_COMMITMENTCONTRACTMETA']._serialized_start=667
  _globals['_COMMITMENTCONTRACTMETA']._serialized_end=760
  _globals['_INSPECTCOMMITMENTCONTRACTSREQUEST']._serialized_start=763
  _globals['_INSPECTCOMMITMENTCONTRACTSREQUEST']._serialized_end=977
  _globals['_INSPECTCOMMITMENTCONTRACTSRESPONSE']._serialized_start=979
  _globals['_INSPECTCOMMITMENTCONTRACTSRESPONSE']._serialized_end=1037
  _globals['_COMMITMENTCONTRACT']._serialized_start=1040
  _globals['_COMMITMENTCONTRACT']._serialized_end=1299
  _globals['_CONTRACTSTATE']._serialized_start=1302
  _globals['_CONTRACTSTATE']._serialized_end=2402
  _globals['_CONTRACTSTATE_SYNCHRONIZERSTATE']._serialized_start=1320
  _globals['_CONTRACTSTATE_SYNCHRONIZERSTATE']._serialized_end=1894
  _globals['_CONTRACTSTATE_CREATED']._serialized_start=1896
  _globals['_CONTRACTSTATE_CREATED']._serialized_end=1905
  _globals['_CONTRACTSTATE_ASSIGNED']._serialized_start=1908
  _globals['_CONTRACTSTATE_ASSIGNED']._serialized_end=2100
  _globals['_CONTRACTSTATE_ARCHIVED']._serialized_start=2102
  _globals['_CONTRACTSTATE_ARCHIVED']._serialized_end=2112
  _globals['_CONTRACTSTATE_UNASSIGNED']._serialized_start=2115
  _globals['_CONTRACTSTATE_UNASSIGNED']._serialized_end=2357
  _globals['_CONTRACTSTATE_UNKNOWN']._serialized_start=2359
  _globals['_CONTRACTSTATE_UNKNOWN']._serialized_end=2368
  _globals['_CONTRACTSTATE_REASSIGNMENTID']._serialized_start=2370
  _globals['_CONTRACTSTATE_REASSIGNMENTID']._serialized_end=2402
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSREQUEST']._serialized_start=2405
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSREQUEST']._serialized_end=2742
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSRESPONSE']._serialized_start=2745
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSRESPONSE']._serialized_end=2896
  _globals['_TIMERANGE']._serialized_start=2899
  _globals['_TIMERANGE']._serialized_end=3040
  _globals['_SYNCHRONIZERTIMERANGE']._serialized_start=3043
  _globals['_SYNCHRONIZERTIMERANGE']._serialized_end=3211
  _globals['_INTERVAL']._serialized_start=3214
  _globals['_INTERVAL']._serialized_end=3376
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_start=3379
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_end=3791
  _globals['_RECEIVEDACSCOMMITMENTPERSYNCHRONIZER']._serialized_start=3794
  _globals['_RECEIVEDACSCOMMITMENTPERSYNCHRONIZER']._serialized_end=3971
  _globals['_SENTACSCOMMITMENT']._serialized_start=3974
  _globals['_SENTACSCOMMITMENT']._serialized_end=4374
  _globals['_SENTACSCOMMITMENTPERSYNCHRONIZER']._serialized_start=4377
  _globals['_SENTACSCOMMITMENTPERSYNCHRONIZER']._serialized_end=4538
  _globals['_LOOKUPSENTACSCOMMITMENTSREQUEST']._serialized_start=4541
  _globals['_LOOKUPSENTACSCOMMITMENTSREQUEST']._serialized_end=4870
  _globals['_LOOKUPSENTACSCOMMITMENTSRESPONSE']._serialized_start=4873
  _globals['_LOOKUPSENTACSCOMMITMENTSRESPONSE']._serialized_end=5008
  _globals['_SLOWCOUNTERPARTICIPANTSYNCHRONIZERCONFIG']._serialized_start=5011
  _globals['_SLOWCOUNTERPARTICIPANTSYNCHRONIZERCONFIG']._serialized_end=5326
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_start=5329
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_end=5488
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_start=5490
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_end=5535
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_start=5537
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_end=5624
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_start=5627
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_end=5787
  _globals['_COUNTERPARTICIPANTINFO']._serialized_start=5790
  _globals['_COUNTERPARTICIPANTINFO']._serialized_end=6105
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSREQUEST']._serialized_start=6108
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSREQUEST']._serialized_end=6305
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSRESPONSE']._serialized_start=6308
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSRESPONSE']._serialized_end=6472
  _globals['_COUNTINFLIGHTREQUEST']._serialized_start=6474
  _globals['_COUNTINFLIGHTREQUEST']._serialized_end=6537
  _globals['_COUNTINFLIGHTRESPONSE']._serialized_start=6539
  _globals['_COUNTINFLIGHTRESPONSE']._serialized_end=6662
  _globals['_PARTICIPANTINSPECTIONSERVICE']._serialized_start=7068
  _globals['_PARTICIPANTINSPECTIONSERVICE']._serialized_end=8863
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendRequest(_message.Message):
    __slots__ = ("tag", "payload")
    TAG_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    tag: str
    payload: bytes
    def __init__(self, tag: _Optional[str] = ..., payload: _Optional[bytes] = ...) -> None: ...

class SendResponse(_message.Message):
    __slots__ = ("rejection_reason",)
    REJECTION_REASON_FIELD_NUMBER: _ClassVar[int]
    rejection_reason: str
    def __init__(self, rejection_reason: _Optional[str] = ...) -> None: ...

class ReadOrderedRequest(_message.Message):
    __slots__ = ("start_height",)
    START_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    start_height: int
    def __init__(self, start_height: _Optional[int] = ...) -> None: ...

class ReadOrderedResponse(_message.Message):
    __slots__ = ("height", "block")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    height: int
    block: _containers.RepeatedCompositeFieldContainer[Ordered]
    def __init__(self, height: _Optional[int] = ..., block: _Optional[_Iterable[_Union[Ordered, _Mapping]]] = ...) -> None: ...

class Ordered(_message.Message):
    __slots__ = ("tag", "payload")
    TAG_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    tag: str
    payload: bytes
    def __init__(self, tag: _Optional[str] = ..., payload: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .daml_lf_pb2 import Archive, ArchivePayload, HashFunction
from . import daml_lf1_pb2, daml_lf2_pb2

__all__ = [
    "Archive",
    "ArchivePayload",
    "HashFunction",
    "daml_lf1_pb2",
    "daml_lf2_pb2",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_read_service_pb2 import ExportTopologySnapshotRequest, ExportTopologySnapshotResponse, ExportTopologySnapshotV2Request, ExportTopologySnapshotV2Response, GenesisStateRequest, GenesisStateResponse, GenesisStateV2Request, GenesisStateV2Response, ListAllRequest, ListAllResponse, ListAvailableStoresRequest, ListAvailableStoresResponse, ListDecentralizedNamespaceDefinitionRequest, ListDecentralizedNamespaceDefinitionResponse, ListMediatorSynchronizerStateRequest, ListMediatorSynchronizerStateResponse, ListNamespaceDelegationRequest, ListNamespaceDelegationResponse, ListOwnerToKeyMappingRequest, ListOwnerToKeyMappingResponse, ListParticipantSynchronizerPermissionRequest, ListParticipantSynchronizerPermissionResponse, ListPartyHostingLimitsRequest, ListPartyHostingLimitsResponse, ListPartyToKeyMappingRequest, ListPartyToKeyMappingResponse, ListPartyToParticipantRequest, ListPartyToParticipantResponse, ListSequencerConnectionSuccessorRequest, ListSequencerConnectionSuccessorResponse, ListSequencerSynchronizerStateRequest, ListSequencerSynchronizerStateResponse, ListSynchronizerParametersStateRequest, ListSynchronizerParametersStateResponse, ListSynchronizerTrustCertificateRequest, ListSynchronizerTrustCertificateResponse, ListSynchronizerUpgradeAnnouncementRequest, ListSynchronizerUpgradeAnnouncementResponse, ListVettedPackagesRequest, ListVettedPackagesResponse, LogicalUpgradeStateRequest, LogicalUpgradeStateResponse

__all__ = [
    "TopologyManagerReadServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerReadServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerReadServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerReadServiceAsyncStub: ...  # type: ignore
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDecentralizedNamespaceDefinitionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToKeyMappingResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]: ...
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerTrustCertificateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerTrustCertificateResponse]: ...
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantSynchronizerPermissionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantSynchronizerPermissionResponse]: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyHostingLimitsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]: ...
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerParametersStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerParametersStateResponse]: ...
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorSynchronizerStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorSynchronizerStateResponse]: ...
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerSynchronizerStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerSynchronizerStateResponse]: ...
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerUpgradeAnnouncementResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerUpgradeAnnouncementResponse]: ...
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerConnectionSuccessorResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerConnectionSuccessorResponse]: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]: ...
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotResponse]: ...
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotV2Response] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotV2Response]: ...
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]: ...
    def GenesisStateV2(self, __1: GenesisStateV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateV2Response] | _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateV2Response]: ...
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[LogicalUpgradeStateResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, LogicalUpgradeStateResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceBlockingStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResponse: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDecentralizedNamespaceDefinitionResponse: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResponse: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToKeyMappingResponse: ...
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerTrustCertificateResponse: ...
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantSynchronizerPermissionResponse: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyHostingLimitsResponse: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResponse: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResponse: ...
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerParametersStateResponse: ...
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorSynchronizerStateResponse: ...
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerSynchronizerStateResponse: ...
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerUpgradeAnnouncementResponse: ...
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerConnectionSuccessorResponse: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResponse: ...
    def ListAll(self, __1: ListAllRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotResponse]: ...
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotV2Response]: ...
    def GenesisState(self, __1: GenesisStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateResponse]: ...
    def GenesisStateV2(self, __1: GenesisStateV2Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateV2Response]: ...
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[LogicalUpgradeStateResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceAsyncStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]: ...  # type: ignore
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]: ...  # type: ignore
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]: ...  # type: ignore
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]: ...  # type: ignore
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerTrustCertificateResponse]: ...  # type: ignore
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantSynchronizerPermissionResponse]: ...  # type: ignore
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]: ...  # type: ignore
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]: ...  # type: ignore
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]: ...  # type: ignore
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerParametersStateResponse]: ...  # type: ignore
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorSynchronizerStateResponse]: ...  # type: ignore
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerSynchronizerStateResponse]: ...  # type: ignore
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerUpgradeAnnouncementResponse]: ...  # type: ignore
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerConnectionSuccessorResponse]: ...  # type: ignore
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]: ...  # type: ignore
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...  # type: ignore
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotResponse]: ...  # type: ignore
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotV2Response]: ...  # type: ignore
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]: ...  # type: ignore
    def GenesisStateV2(self, __1: GenesisStateV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateV2Response]: ...  # type: ignore
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, LogicalUpgradeStateResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
"""Contains all the data models used in inputs/outputs"""

from .allocate_external_party_request import AllocateExternalPartyRequest
from .allocate_external_party_response import AllocateExternalPartyResponse
from .allocate_party_request import AllocatePartyRequest
from .allocate_party_response import AllocatePartyResponse
from .archived_event import ArchivedEvent
from .command_type_0 import CommandType0
from .command_type_1 import CommandType1
from .command_type_2 import CommandType2
from .command_type_3 import CommandType3
from .completion_stream_request import CompletionStreamRequest
from .connected_synchronizer import ConnectedSynchronizer
from .connected_synchronizer_permission import ConnectedSynchronizerPermission
from .create_and_exercise_command import CreateAndExerciseCommand
from .create_command import CreateCommand
from .create_identity_provider_config_request import CreateIdentityProviderConfigRequest
from .create_identity_provider_config_response import (
    CreateIdentityProviderConfigResponse,
)
from .create_user_response import CreateUserResponse
from .created_event import CreatedEvent
from .created_tree_event import CreatedTreeEvent
from .deduplication_duration import DeduplicationDuration
from .deduplication_offset import DeduplicationOffset
from .deduplication_period_type_0 import DeduplicationPeriodType0
from .deduplication_period_type_1 import DeduplicationPeriodType1
from .deduplication_period_type_2 import DeduplicationPeriodType2
from .delete_identity_provider_config_response import (
    DeleteIdentityProviderConfigResponse,
)
from .delete_v2_users_user_id_response_200 import DeleteV2UsersUserIdResponse200
from .disclosed_contract import DisclosedContract
from .duration import Duration
from .empty import Empty
from .event_type_0 import EventType0
from .event_type_1 import EventType1
from .event_type_2 import EventType2
from .execute_submission_and_wait_response import ExecuteSubmissionAndWaitResponse
from .execute_submission_response import ExecuteSubmissionResponse
from .exercise_by_key_command import ExerciseByKeyCommand
from .exercise_command import ExerciseCommand
from .exercised_event import ExercisedEvent
from .exercised_tree_event import ExercisedTreeEvent
from .experimental_command_inspection_service import (
    ExperimentalCommandInspectionService,
)
from .experimental_features import ExperimentalFeatures
from .experimental_static_time import ExperimentalStaticTime
from .features_descriptor import FeaturesDescriptor
from .field import Field
from .field_mask import FieldMask
from .generate_external_party_topology_request import (
    GenerateExternalPartyTopologyRequest,
)
from .generate_external_party_topology_response import (
    GenerateExternalPartyTopologyResponse,
)
from .get_connected_synchronizers_response import GetConnectedSynchronizersResponse
from .get_identity_provider_config_response import GetIdentityProviderConfigResponse
from .get_latest_pruned_offsets_response import GetLatestPrunedOffsetsResponse
from .get_ledger_api_version_response import GetLedgerApiVersionResponse
from .get_ledger_end_response import GetLedgerEndResponse
from .get_package_status_response import GetPackageStatusResponse
from .get_package_status_response_package_status import (
    GetPackageStatusResponsePackageStatus,
)
from .get_participant_id_response import GetParticipantIdResponse
from .get_parties_response import GetPartiesResponse
from .get_preferred_package_version_response import GetPreferredPackageVersionResponse
from .get_preferred_packages_request import GetPreferredPackagesRequest
from .get_preferred_packages_response import GetPreferredPackagesResponse
from .get_user_response import GetUserResponse
from .identifier import Identifier
from .identity_provider_config import IdentityProviderConfig
from .js_active_contract import JsActiveContract
from .js_archived import JsArchived
from .js_assigned_event import JsAssignedEvent
from .js_assignment_event import JsAssignmentEvent
from .js_canton_error import JsCantonError
from .js_commands import JsCommands
from .js_contract_entry_type_0 import JsContractEntryType0
from .js_contract_entry_type_1 import JsContractEntryType1
from .js_contract_entry_type_2 import JsContractEntryType2
from .js_contract_entry_type_3 import JsContractEntryType3
from .js_created import JsCreated
from .js_empty import JsEmpty
from .js_execute_submission_and_wait_for_transaction_response import (
    JsExecuteSubmissionAndWaitForTransactionResponse,
)
from .js_get_active_contracts_response import JsGetActiveContractsResponse
from .js_get_events_by_contract_id_response import JsGetEventsByContractIdResponse
from .js_get_transaction_response import JsGetTransactionResponse
from .js_get_transaction_tree_response import JsGetTransactionTreeResponse
from .js_incomplete_assigned import JsIncompleteAssigned
from .js_incomplete_unassigned import JsIncompleteUnassigned
from .js_interface_view import JsInterfaceView
from .js_prepare_submission_response import JsPrepareSubmissionResponse
from .js_prepare_submission_response_hashing_scheme_version import (
    JsPrepareSubmissionResponseHashingSchemeVersion,
)
from .js_reassignment import JsReassignment
from .js_reassignment_event_type_0 import JsReassignmentEventType0
from .js_reassignment_event_type_1 import JsReassignmentEventType1
from .js_status import JsStatus
from .js_submit_and_wait_for_reassignment_response import (
    JsSubmitAndWaitForReassignmentResponse,
)
from .js_submit_and_wait_for_transaction_response import (
    JsSubmitAndWaitForTransactionResponse,
)
from .js_submit_and_wait_for_transaction_tree_response import (
    JsSubmitAndWaitForTransactionTreeResponse,
)
from .js_transaction import JsTransaction
from .js_transaction_tree import JsTransactionTree
from .js_unassigned_event import JsUnassignedEvent
from .list_identity_provider_configs_response import ListIdentityProviderConfigsResponse
from .list_known_parties_response import ListKnownPartiesResponse
from .list_packages_response import ListPackagesResponse
from .list_users_response import ListUsersResponse
from .list_vetted_packages_request import ListVettedPackagesRequest
from .list_vetted_packages_response import ListVettedPackagesResponse
from .map_int_field import MapIntField
from .map_int_tree_event import MapIntTreeEvent
from .map_string import MapString
from .min_ledger_time_abs import MinLedgerTimeAbs
from .min_ledger_time_rel import MinLedgerTimeRel
from .no_prior import NoPrior
from .object_meta import ObjectMeta
from .offset_checkpoint_feature import OffsetCheckpointFeature
from .package_feature import PackageFeature
from .package_metadata_filter import PackageMetadataFilter
from .package_preference import PackagePreference
from .package_reference import PackageReference
from .package_vetting_requirement import PackageVettingRequirement
from .participant_authorization_topology_format import (
    ParticipantAuthorizationTopologyFormat,
)
from .party_details import PartyDetails
from .party_management_feature import PartyManagementFeature
from .party_signatures import PartySignatures
from .prefetch_contract_key import PrefetchContractKey
from .prior import Prior
from .proto_any import ProtoAny
from .reassignment import Reassignment
from .signature import Signature
from .signed_transaction import SignedTransaction
from .signing_public_key import SigningPublicKey
from .single_party_signatures import SinglePartySignatures
from .submit_and_wait_response import SubmitAndWaitResponse
from .submit_reassignment_response import SubmitReassignmentResponse
from .submit_response import SubmitResponse
from .synchronizer_time import SynchronizerTime
from .topology_format import TopologyFormat
from .topology_state_filter import TopologyStateFilter
from .trace_context import TraceContext
from .transaction import Transaction
from .transaction_format_transaction_shape import TransactionFormatTransactionShape
from .transaction_tree import TransactionTree
from .tree_event_type_0 import TreeEventType0
from .tree_event_type_1 import TreeEventType1
from .unassigned_event import UnassignedEvent
from .unknown_field_set import UnknownFieldSet
from .update_identity_provider_config_request import UpdateIdentityProviderConfigRequest
from .update_identity_provider_config_response import (
    UpdateIdentityProviderConfigResponse,
)
from .update_party_details_request import UpdatePartyDetailsRequest
from .update_party_details_response import UpdatePartyDetailsResponse
from .update_user_identity_provider_id_request import (
    UpdateUserIdentityProviderIdRequest,
)
from .update_user_identity_provider_id_response import (
    UpdateUserIdentityProviderIdResponse,
)
from .update_user_request import UpdateUserRequest
from .update_user_response import UpdateUserResponse
from .upload_dar_file_response import UploadDarFileResponse
from .user import User
from .user_management_feature import UserManagementFeature
from .vetted_package import VettedPackage
from .vetted_packages_ref import VettedPackagesRef

__all__ = (
    "AllocateExternalPartyRequest",
    "AllocateExternalPartyResponse",
    "AllocatePartyRequest",
    "AllocatePartyResponse",
    "ArchivedEvent",
    "CommandType0",
    "CommandType1",
    "CommandType2",
    "CommandType3",
    "CompletionStreamRequest",
    "ConnectedSynchronizer",
    "ConnectedSynchronizerPermission",
    "CreateAndExerciseCommand",
    "CreateCommand",
    "CreatedEvent",
    "CreatedTreeEvent",
    "CreateIdentityProviderConfigRequest",
    "CreateIdentityProviderConfigResponse",
    "CreateUserResponse",
    "DeduplicationDuration",
    "DeduplicationOffset",
    "DeduplicationPeriodType0",
    "DeduplicationPeriodType1",
    "DeduplicationPeriodType2",
    "DeleteIdentityProviderConfigResponse",
    "DeleteV2UsersUserIdResponse200",
    "DisclosedContract",
    "Duration",
    "Empty",
    "EventType0",
    "EventType1",
    "EventType2",
    "ExecuteSubmissionAndWaitResponse",
    "ExecuteSubmissionResponse",
    "ExerciseByKeyCommand",
    "ExerciseCommand",
    "ExercisedEvent",
    "ExercisedTreeEvent",
    "ExperimentalCommandInspectionService",
    "ExperimentalFeatures",
    "ExperimentalStaticTime",
    "FeaturesDescriptor",
    "Field",
    "FieldMask",
    "GenerateExternalPartyTopologyRequest",
    "GenerateExternalPartyTopologyResponse",
    "GetConnectedSynchronizersResponse",
    "GetIdentityProviderConfigResponse",
    "GetLatestPrunedOffsetsResponse",
    "GetLedgerApiVersionResponse",
    "GetLedgerEndResponse",
    "GetPackageStatusResponse",
    "GetPackageStatusResponsePackageStatus",
    "GetParticipantIdResponse",
    "GetPartiesResponse",
    "GetPreferredPackagesRequest",
    "GetPreferredPackagesResponse",
    "GetPreferredPackageVersionResponse",
    "GetUserResponse",
    "Identifier",
    "IdentityProviderConfig",
    "JsActiveContract",
    "JsArchived",
    "JsAssignedEvent",
    "JsAssignmentEvent",
    "JsCantonError",
    "JsCommands",
    "JsContractEntryType0",
    "JsContractEntryType1",
    "JsContractEntryType2",
    "JsContractEntryType3",
    "JsCreated",
    "JsEmpty",
    "JsExecuteSubmissionAndWaitForTransactionResponse",
    "JsGetActiveContractsResponse",
    "JsGetEventsByContractIdResponse",
    "JsGetTransactionResponse",
    "JsGetTransactionTreeResponse",
    "JsIncompleteAssigned",
    "JsIncompleteUnassigned",
    "JsInterfaceView",
    "JsPrepareSubmissionResponse",
    "JsPrepareSubmissionResponseHashingSchemeVersion",
    "JsReassignment",
    "JsReassignmentEventType0",
    "JsReassignmentEventType1",
    "JsStatus",
    "JsSubmitAndWaitForReassignmentResponse",
    "JsSubmitAndWaitForTransactionResponse",
    "JsSubmitAndWaitForTransactionTreeResponse",
    "JsTransaction",
    "JsTransactionTree",
    "JsUnassignedEvent",
    "ListIdentityProviderConfigsResponse",
    "ListKnownPartiesResponse",
    "ListPackagesResponse",
    "ListUsersResponse",
    "ListVettedPackagesRequest",
    "ListVettedPackagesResponse",
    "MapIntField",
    "MapIntTreeEvent",
    "MapString",
    "MinLedgerTimeAbs",
    "MinLedgerTimeRel",
    "NoPrior",
    "ObjectMeta",
    "OffsetCheckpointFeature",
    "PackageFeature",
    "PackageMetadataFilter",
    "PackagePreference",
    "PackageReference",
    "PackageVettingRequirement",
    "ParticipantAuthorizationTopologyFormat",
    "PartyDetails",
    "PartyManagementFeature",
    "PartySignatures",
    "PrefetchContractKey",
    "Prior",
    "ProtoAny",
    "Reassignment",
    "Signature",
    "SignedTransaction",
    "SigningPublicKey",
    "SinglePartySignatures",
    "SubmitAndWaitResponse",
    "SubmitReassignmentResponse",
    "SubmitResponse",
    "SynchronizerTime",
    "TopologyFormat",
    "TopologyStateFilter",
    "TraceContext",
    "Transaction",
    "TransactionFormatTransactionShape",
    "TransactionTree",
    "TreeEventType0",
    "TreeEventType1",
    "UnassignedEvent",
    "UnknownFieldSet",
    "UpdateIdentityProviderConfigRequest",
    "UpdateIdentityProviderConfigResponse",
    "UpdatePartyDetailsRequest",
    "UpdatePartyDetailsResponse",
    "UpdateUserIdentityProviderIdRequest",
    "UpdateUserIdentityProviderIdResponse",
    "UpdateUserRequest",
    "UpdateUserResponse",
    "UploadDarFileResponse",
    "User",
    "UserManagementFeature",
    "VettedPackage",
    "VettedPackagesRef",
)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.proto_any import ProtoAny


T = TypeVar("T", bound="JsStatus")


@_attrs_define
class JsStatus:
    """
    Attributes:
        code (int):
        message (str):
        details (list[ProtoAny] | Unset):
    """

    code: int
    message: str
    details: list[ProtoAny] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        code = self.code

        message = self.message

        details: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.details, Unset):
            details = []
            for details_item_data in self.details:
                details_item = details_item_data.to_dict()
                details.append(details_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "code": code,
                "message": message,
            }
        )
        if details is not UNSET:
            field_dict["details"] = details

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.proto_any import ProtoAny

        d = dict(src_dict)
        code = d.pop("code")

        message = d.pop("message")

        _details = d.pop("details", UNSET)
        details: list[ProtoAny] | Unset = UNSET
        if _details is not UNSET:
            details = []
            for details_item_data in _details:
                details_item = ProtoAny.from_dict(details_item_data)

                details.append(details_item)

        js_status = cls(
            code=code,
            message=message,
            details=details,
        )

        js_status.additional_properties = d
        return js_status

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyQueueStatus(_message.Message):
    __slots__ = ("manager", "dispatcher", "clients")
    MANAGER_FIELD_NUMBER: _ClassVar[int]
    DISPATCHER_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    manager: int
    dispatcher: int
    clients: int
    def __init__(self, manager: _Optional[int] = ..., dispatcher: _Optional[int] = ..., clients: _Optional[int] = ...) -> None: ...

class ComponentStatus(_message.Message):
    __slots__ = ("name", "ok", "degraded", "failed", "fatal")
    class StatusData(_message.Message):
        __slots__ = ("description",)
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        description: str
        def __init__(self, description: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    OK_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_FIELD_NUMBER: _ClassVar[int]
    FAILED_FIELD_NUMBER: _ClassVar[int]
    FATAL_FIELD_NUMBER: _ClassVar[int]
    name: str
    ok: ComponentStatus.StatusData
    degraded: ComponentStatus.StatusData
    failed: ComponentStatus.StatusData
    fatal: ComponentStatus.StatusData
    def __init__(self, name: _Optional[str] = ..., ok: _Optional[_Union[ComponentStatus.StatusData, _Mapping]] = ..., degraded: _Optional[_Union[ComponentStatus.StatusData, _Mapping]] = ..., failed: _Optional[_Union[ComponentStatus.StatusData, _Mapping]] = ..., fatal: _Optional[_Union[ComponentStatus.StatusData, _Mapping]] = ...) -> None: ...

class NotInitialized(_message.Message):
    __slots__ = ("active", "waiting_for_external_input")
    class WaitingForExternalInput(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED: _ClassVar[NotInitialized.WaitingForExternalInput]
        WAITING_FOR_EXTERNAL_INPUT_ID: _ClassVar[NotInitialized.WaitingForExternalInput]
        WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY: _ClassVar[NotInitialized.WaitingForExternalInput]
        WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION: _ClassVar[NotInitialized.WaitingForExternalInput]
    WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED: NotInitialized.WaitingForExternalInput
    WAITING_FOR_EXTERNAL_INPUT_ID: NotInitialized.WaitingForExternalInput
    WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY: NotInitialized.WaitingForExternalInput
    WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION: NotInitialized.WaitingForExternalInput
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    WAITING_FOR_EXTERNAL_INPUT_FIELD_NUMBER: _ClassVar[int]
    active: bool
    waiting_for_external_input: NotInitialized.WaitingForExternalInput
    def __init__(self, active: bool = ..., waiting_for_external_input: _Optional[_Union[NotInitialized.WaitingForExternalInput, str]] = ...) -> None: ...

class Status(_message.Message):
    __slots__ = ("uid", "uptime", "ports", "active", "topology_queues", "components", "version")
    class PortsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    UID_FIELD_NUMBER: _ClassVar[int]
    UPTIME_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_QUEUES_FIELD_NUMBER: _ClassVar[int]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    uid: str
    uptime: _duration_pb2.Duration
    ports: _containers.ScalarMap[str, int]
    active: bool
    topology_queues: TopologyQueueStatus
    components: _containers.RepeatedCompositeFieldContainer[ComponentStatus]
    version: str
    def __init__(self, uid: _Optional[str] = ..., uptime: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., ports: _Optional[_Mapping[str, int]] = ..., active: bool = ..., topology_queues: _Optional[_Union[TopologyQueueStatus, _Mapping]] = ..., components: _Optional[_Iterable[_Union[ComponentStatus, _Mapping]]] = ..., version: _Optional[str] = ...) -> None: ...

class HealthDumpRequest(_message.Message):
    __slots__ = ("chunk_size",)
    CHUNK_SIZE_FIELD_NUMBER: _ClassVar[int]
    chunk_size: int
    def __init__(self, chunk_size: _Optional[int] = ...) -> None: ...

class HealthDumpResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class SetLogLevelRequest(_message.Message):
    __slots__ = ("level",)
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    level: str
    def __init__(self, level: _Optional[str] = ...) -> None: ...

class SetLogLevelResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLastErrorsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLastErrorsResponse(_message.Message):
    __slots__ = ("errors",)
    class Error(_message.Message):
        __slots__ = ("trace_id", "message")
        TRACE_ID_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        trace_id: str
        message: str
        def __init__(self, trace_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    errors: _containers.RepeatedCompositeFieldContainer[GetLastErrorsResponse.Error]
    def __init__(self, errors: _Optional[_Iterable[_Union[GetLastErrorsResponse.Error, _Mapping]]] = ...) -> None: ...

class GetLastErrorTraceRequest(_message.Message):
    __slots__ = ("trace_id",)
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    trace_id: str
    def __init__(self, trace_id: _Optional[str] = ...) -> None: ...

class GetLastErrorTraceResponse(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, messages: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/active_contract.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/active_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/active_contract.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc4\x01\n\x11\x41\x63tiveContractOld\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12S\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.ContractR\x08\x63ontract\x12\x31\n\x14reassignment_counter\x18\x03 \x01(\x03R\x13reassignmentCounter\"\x9b\x05\n\x08\x43ontract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x32\n\x15raw_contract_instance\x18\x02 \x01(\x0cR\x13rawContractInstance\x12\\\n\x08metadata\x18\x03 \x01(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.Contract.MetadataR\x08metadata\x12H\n\x12ledger_create_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10ledgerCreateTime\x12/\n\x13\x61uthentication_data\x18\x05 \x01(\x0cR\x12\x61uthenticationData\x1a\xfd\x01\n\x08Metadata\x12<\n\x1anon_maintainer_signatories\x18\x01 \x03(\tR\x18nonMaintainerSignatories\x12<\n\x1anon_signatory_stakeholders\x18\x02 \x03(\tR\x18nonSignatoryStakeholders\x12S\n\x03key\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.Contract.GlobalKeyR\x03key\x12 \n\x0bmaintainers\x18\x04 \x03(\tR\x0bmaintainers\x1a\x61\n\tGlobalKey\x12\x1f\n\x0btemplate_id\x18\x01 \x01(\x0cR\ntemplateId\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\"9\n\x0e\x41\x63tiveContract\x12\'\n\x0f\x61\x63tive_contract\x18\x01 \x01(\x0cR\x0e\x61\x63tiveContractB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.active_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_ACTIVECONTRACTOLD']._serialized_start=152
  _globals['_ACTIVECONTRACTOLD']._serialized_end=348
  _globals['_CONTRACT']._serialized_start=351
  _globals['_CONTRACT']._serialized_end=1018
  _globals['_CONTRACT_METADATA']._serialized_start=666
  _globals['_CONTRACT_METADATA']._serialized_end=919
  _globals['_CONTRACT_GLOBALKEY']._serialized_start=921
  _globals['_CONTRACT_GLOBALKEY']._serialized_end=1018
  _globals['_ACTIVECONTRACT']._serialized_start=1020
  _globals['_ACTIVECONTRACT']._serialized_end=1077
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/commands.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%com/daml/ledger/api/v2/commands.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x02\n\x07\x43ommand\x12?\n\x06\x63reate\x18\x01 \x01(\x0b\x32%.com.daml.ledger.api.v2.CreateCommandH\x00R\x06\x63reate\x12\x45\n\x08\x65xercise\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.ExerciseCommandH\x00R\x08\x65xercise\x12V\n\x0f\x65xercise_by_key\x18\x04 \x01(\x0b\x32,.com.daml.ledger.api.v2.ExerciseByKeyCommandH\x00R\rexerciseByKey\x12\x62\n\x13\x63reate_and_exercise\x18\x03 \x01(\x0b\x32\x30.com.daml.ledger.api.v2.CreateAndExerciseCommandH\x00R\x11\x63reateAndExerciseB\t\n\x07\x63ommand\"\x9f\x01\n\rCreateCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\x0f\x63reateArguments\"\xd7\x01\n\x0f\x45xerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x63hoiceArgument\"\xfd\x01\n\x14\x45xerciseByKeyCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63ontractKey\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x63hoiceArgument\"\x8a\x02\n\x18\x43reateAndExerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\x0f\x63reateArguments\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x63hoiceArgument\"\xd0\x01\n\x11\x44isclosedContract\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12,\n\x12\x63reated_event_blob\x18\x03 \x01(\x0cR\x10\x63reatedEventBlob\x12\'\n\x0fsynchronizer_id\x18\x04 \x01(\tR\x0esynchronizerId\"\xda\x06\n\x08\x43ommands\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12;\n\x08\x63ommands\x18\x04 \x03(\x0b\x32\x1f.com.daml.ledger.api.v2.CommandR\x08\x63ommands\x12R\n\x16\x64\x65\x64uplication_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x06 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12I\n\x13min_ledger_time_abs\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10minLedgerTimeAbs\x12H\n\x13min_ledger_time_rel\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10minLedgerTimeRel\x12\x15\n\x06\x61\x63t_as\x18\t \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\n \x03(\tR\x06readAs\x12#\n\rsubmission_id\x18\x0b \x01(\tR\x0csubmissionId\x12Z\n\x13\x64isclosed_contracts\x18\x0c \x03(\x0b\x32).com.daml.ledger.api.v2.DisclosedContractR\x12\x64isclosedContracts\x12\'\n\x0fsynchronizer_id\x18\r \x01(\tR\x0esynchronizerId\x12\x45\n\x1fpackage_id_selection_preference\x18\x0e \x03(\tR\x1cpackageIdSelectionPreference\x12\x61\n\x16prefetch_contract_keys\x18\x0f \x03(\x0b\x32+.com.daml.ledger.api.v2.PrefetchContractKeyR\x14prefetchContractKeysB\x16\n\x14\x64\x65\x64uplication_period\"\x9c\x01\n\x13PrefetchContractKey\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63ontractKeyB\x8c\x01\n\x16\x63om.daml.ledger.api.v2B\x12\x43ommandsOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\022CommandsOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_COMMAND']._serialized_start=167
  _globals['_COMMAND']._serialized_end=511
  _globals['_CREATECOMMAND']._serialized_start=514
  _globals['_CREATECOMMAND']._serialized_end=673
  _globals['_EXERCISECOMMAND']._serialized_start=676
  _globals['_EXERCISECOMMAND']._serialized_end=891
  _globals['_EXERCISEBYKEYCOMMAND']._serialized_start=894
  _globals['_EXERCISEBYKEYCOMMAND']._serialized_end=1147
  _globals['_CREATEANDEXERCISECOMMAND']._serialized_start=1150
  _globals['_CREATEANDEXERCISECOMMAND']._serialized_end=1416
  _globals['_DISCLOSEDCONTRACT']._serialized_start=1419
  _globals['_DISCLOSEDCONTRACT']._serialized_end=1627
  _globals['_COMMANDS']._serialized_start=1630
  _globals['_COMMANDS']._serialized_end=2488
  _globals['_PREFETCHCONTRACTKEY']._serialized_start=2491
  _globals['_PREFETCHCONTRACTKEY']._serialized_end=2647
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .participant_inspection_service_pb2 import CountInFlightRequest, CountInFlightResponse, GetConfigForSlowCounterParticipantsRequest, GetConfigForSlowCounterParticipantsResponse, GetIntervalsBehindForCounterParticipantsRequest, GetIntervalsBehindForCounterParticipantsResponse, InspectCommitmentContractsRequest, InspectCommitmentContractsResponse, LookupOffsetByTimeRequest, LookupOffsetByTimeResponse, LookupReceivedAcsCommitmentsRequest, LookupReceivedAcsCommitmentsResponse, LookupSentAcsCommitmentsRequest, LookupSentAcsCommitmentsResponse, OpenCommitmentRequest, OpenCommitmentResponse, SetConfigForSlowCounterParticipantsRequest, SetConfigForSlowCounterParticipantsResponse

__all__ = [
    "ParticipantInspectionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class ParticipantInspectionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _ParticipantInspectionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _ParticipantInspectionServiceAsyncStub: ...  # type: ignore
    def LookupOffsetByTime(self, __1: LookupOffsetByTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByTimeResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTimeResponse]: ...
    def OpenCommitment(self, __1: OpenCommitmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[OpenCommitmentResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, OpenCommitmentResponse]: ...
    def InspectCommitmentContracts(self, __1: InspectCommitmentContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[InspectCommitmentContractsResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, InspectCommitmentContractsResponse]: ...
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitmentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupSentAcsCommitmentsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupSentAcsCommitmentsResponse]: ...
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitmentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupReceivedAcsCommitmentsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupReceivedAcsCommitmentsResponse]: ...
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetConfigForSlowCounterParticipantsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetConfigForSlowCounterParticipantsResponse]: ...
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConfigForSlowCounterParticipantsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetConfigForSlowCounterParticipantsResponse]: ...
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetIntervalsBehindForCounterParticipantsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetIntervalsBehindForCounterParticipantsResponse]: ...
    def CountInFlight(self, __1: CountInFlightRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CountInFlightResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, CountInFlightResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantInspectionServiceBlockingStub(ParticipantInspectionServiceStub):
    def LookupOffsetByTime(self, __1: LookupOffsetByTimeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByTimeResponse: ...
    def OpenCommitment(self, __1: OpenCommitmentRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[OpenCommitmentResponse]: ...
    def InspectCommitmentContracts(self, __1: InspectCommitmentContractsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[InspectCommitmentContractsResponse]: ...
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitmentsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupSentAcsCommitmentsResponse: ...
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitmentsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupReceivedAcsCommitmentsResponse: ...
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipantsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetConfigForSlowCounterParticipantsResponse: ...
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipantsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConfigForSlowCounterParticipantsResponse: ...
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipantsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetIntervalsBehindForCounterParticipantsResponse: ...
    def CountInFlight(self, __1: CountInFlightRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CountInFlightResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantInspectionServiceAsyncStub(ParticipantInspectionServiceStub):
    def LookupOffsetByTime(self, __1: LookupOffsetByTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTimeResponse]: ...  # type: ignore
    def OpenCommitment(self, __1: OpenCommitmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, OpenCommitmentResponse]: ...  # type: ignore
    def InspectCommitmentContracts(self, __1: InspectCommitmentContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, InspectCommitmentContractsResponse]: ...  # type: ignore
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitmentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupSentAcsCommitmentsResponse]: ...  # type: ignore
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitmentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupReceivedAcsCommitmentsResponse]: ...  # type: ignore
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetConfigForSlowCounterParticipantsResponse]: ...  # type: ignore
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetConfigForSlowCounterParticipantsResponse]: ...  # type: ignore
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipantsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetIntervalsBehindForCounterParticipantsResponse]: ...  # type: ignore
    def CountInFlight(self, __1: CountInFlightRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, CountInFlightResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import sequencer_bft_administration_service_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerBftAdministrationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddPeerEndpoint = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/AddPeerEndpoint',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointResponse.FromString,
                _registered_method=True)
        self.RemovePeerEndpoint = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/RemovePeerEndpoint',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointResponse.FromString,
                _registered_method=True)
        self.GetPeerNetworkStatus = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/GetPeerNetworkStatus',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusResponse.FromString,
                _registered_method=True)
        self.GetOrderingTopology = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/GetOrderingTopology',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyResponse.FromString,
                _registered_method=True)
        self.SetPerformanceMetricsEnabled = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/SetPerformanceMetricsEnabled',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledResponse.FromString,
                _registered_method=True)


class SequencerBftAdministrationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddPeerEndpoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePeerEndpoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeerNetworkStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrderingTopology(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPerformanceMetricsEnabled(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerBftAdministrationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddPeerEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPeerEndpoint,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointResponse.SerializeToString,
            ),
            'RemovePeerEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePeerEndpoint,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointResponse.SerializeToString,
            ),
            'GetPeerNetworkStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeerNetworkStatus,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusResponse.SerializeToString,
            ),
            'GetOrderingTopology': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrderingTopology,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyResponse.SerializeToString,
            ),
            'SetPerformanceMetricsEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPerformanceMetricsEnabled,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerBftAdministrationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddPeerEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/AddPeerEndpoint',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.AddPeerEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemovePeerEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/RemovePeerEndpoint',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.RemovePeerEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPeerNetworkStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/GetPeerNetworkStatus',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetPeerNetworkStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOrderingTopology(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/GetOrderingTopology',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.GetOrderingTopologyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetPerformanceMetricsEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerBftAdministrationService/SetPerformanceMetricsEnabled',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__bft__administration__service__pb2.SetPerformanceMetricsEnabledResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/mediator_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/domain/admin/v0/mediator_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....health.admin.v0 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v0_dot_status__service__pb2
from ....health.admin.v1 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v1_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/domain/admin/v0/mediator_status_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a<com/digitalasset/canton/health/admin/v0/status_service.proto\x1a<com/digitalasset/canton/health/admin/v1/status_service.proto\"\x17\n\x15MediatorStatusRequest\"\x8d\x04\n\x16MediatorStatusResponse\x12v\n\x06status\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.domain.admin.v0.MediatorStatusResponse.MediatorStatusResponseStatusH\x00R\x06status\x12\x66\n\x0bunavailable\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.health.admin.v0.NodeStatus.NotInitializedH\x00R\x0bunavailable\x12L\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x30.com.digitalasset.canton.health.admin.v1.FailureH\x00R\x07\x66\x61ilure\x1a\xbc\x01\n\x1cMediatorStatusResponseStatus\x12T\n\rcommon_status\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.health.admin.v1.StatusR\x0c\x63ommonStatus\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12)\n\x10protocol_version\x18\x03 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind2\xab\x01\n\x15MediatorStatusService\x12\x91\x01\n\x0eMediatorStatus\x12>.com.digitalasset.canton.domain.admin.v0.MediatorStatusRequest\x1a?.com.digitalasset.canton.domain.admin.v0.MediatorStatusResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.mediator_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_MEDIATORSTATUSREQUEST']._serialized_start=238
  _globals['_MEDIATORSTATUSREQUEST']._serialized_end=261
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_start=264
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_end=789
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_start=593
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_end=781
  _globals['_MEDIATORSTATUSSERVICE']._serialized_start=792
  _globals['_MEDIATORSTATUSSERVICE']._serialized_end=963
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.package_vetting_requirement import PackageVettingRequirement


T = TypeVar("T", bound="GetPreferredPackagesRequest")


@_attrs_define
class GetPreferredPackagesRequest:
    """
    Attributes:
        synchronizer_id (str): The synchronizer whose vetting state should be used for resolving this query.
            If not specified, the vetting states of all synchronizers to which the participant is connected are used.
            Optional
        package_vetting_requirements (list[PackageVettingRequirement] | Unset): The package-name vetting requirements
            for which the preferred packages should be resolved.

            Generally it is enough to provide the requirements for the intended command's root package-names.
            Additional package-name requirements can be provided when additional Daml transaction informees need to use
            package dependencies of the command's root packages.

            Required
        vetting_valid_at (str | Unset): The timestamp at which the package vetting validity should be computed
            on the latest topology snapshot as seen by the participant.
            If not provided, the participant's current clock time is used.
            Optional
    """

    synchronizer_id: str
    package_vetting_requirements: list[PackageVettingRequirement] | Unset = UNSET
    vetting_valid_at: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        synchronizer_id = self.synchronizer_id

        package_vetting_requirements: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.package_vetting_requirements, Unset):
            package_vetting_requirements = []
            for (
                package_vetting_requirements_item_data
            ) in self.package_vetting_requirements:
                package_vetting_requirements_item = (
                    package_vetting_requirements_item_data.to_dict()
                )
                package_vetting_requirements.append(package_vetting_requirements_item)

        vetting_valid_at = self.vetting_valid_at

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "synchronizerId": synchronizer_id,
            }
        )
        if package_vetting_requirements is not UNSET:
            field_dict["packageVettingRequirements"] = package_vetting_requirements
        if vetting_valid_at is not UNSET:
            field_dict["vettingValidAt"] = vetting_valid_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.package_vetting_requirement import PackageVettingRequirement

        d = dict(src_dict)
        synchronizer_id = d.pop("synchronizerId")

        _package_vetting_requirements = d.pop("packageVettingRequirements", UNSET)
        package_vetting_requirements: list[PackageVettingRequirement] | Unset = UNSET
        if _package_vetting_requirements is not UNSET:
            package_vetting_requirements = []
            for package_vetting_requirements_item_data in _package_vetting_requirements:
                package_vetting_requirements_item = PackageVettingRequirement.from_dict(
                    package_vetting_requirements_item_data
                )

                package_vetting_requirements.append(package_vetting_requirements_item)

        vetting_valid_at = d.pop("vettingValidAt", UNSET)

        get_preferred_packages_request = cls(
            synchronizer_id=synchronizer_id,
            package_vetting_requirements=package_vetting_requirements,
            vetting_valid_at=vetting_valid_at,
        )

        get_preferred_packages_request.additional_properties = d
        return get_preferred_packages_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
